import React from 'react';
import { ConfigProvider } from 'antd';
import classNames from 'classnames';

import '../styles/common.less';
import './index.less';

// "caseType":"待办工单","flowName":"维修处理流程","nodeName":"审核关单","content":"请迅速到现场处理","time":"2020-11-03 09:11:12"
export class CaseContent {
  // eslint-disable-next-line no-use-before-define
  constructor({ caseType, flowName, nodeName, content, time } = content) {
    this.caseType = caseType;
    this.flowName = flowName;
    this.nodeName = nodeName;
    this.content = content;
    this.time = time;
  }
}

const Case = ({ message, confirmRead }) => {
  const { getPrefixCls } = React.useContext(ConfigProvider.ConfigContext);
  const prefixCls = getPrefixCls();
  const caseType = message?.infoContent?.caseType;
  const flowName = message?.infoContent?.flowName;
  const nodeName = message?.infoContent?.nodeName;
  const flowNo = message?.infoContent?.flowNo;
  const content = message?.infoContent?.content;

  const goPath = item => {
    confirmRead(false, [message.id]);
    const messageType = item.messType;
    let label = '';
    let widgetID = '';
    switch (messageType) {
      case '任务派发':
        label = '任务派发';
        widgetID = 'widget_city_综合运营_二供管理_维修管理_工单办理';
        break;
      case '任务驳回':
        label = '任务驳回';
        widgetID = 'widget_city_综合运营_二供管理_维修管理_工单办理';
        // eslint-disable-next-line no-underscore-dangle,no-case-declarations
        let _tab;
        // eslint-disable-next-line prefer-const
        _tab = '任务驳回';
        break;
      default:
        label = '工单办理';
        widgetID = 'widget_city_综合运营_二供管理_维修管理_工单办理';
        break;
    }
    const webPath = item.webPath || 'product/maintenance/CaseManage/CaseDoingBox/StardCaseDoingBoxView|isDelay=1';
    window.share.event.emit('listenerMointer', {
      widgetId: widgetID,
      label,
      url: webPath,
    });
  };

  return (
    <div
      className={classNames(`${prefixCls}-notifier-message_case`, `${prefixCls}-notifier-message-container`)}
      title="点击查看详情"
      onClick={() => goPath(message)}
    >
      <div className={`${prefixCls}-notifier-message-title`}>
        <span>{caseType}</span>
        <img
          className={`${prefixCls}-notifier-message-confirm`}
          title="点击标为已读"
          onClick={e => {
            e.stopPropagation();
            confirmRead(false, [message.id]);
          }}
          src={require('../../images/oper/ok_line.png')}
        />
      </div>
      <div className={`${prefixCls}-notifier-message-content`}>
        <p className={`${prefixCls}-notifier-message_case-flowinfo`}>
          <span>{flowName}</span>
          <span>，</span>
          <span>{nodeName}</span>
        </p>
        {flowNo && (
          <p>
            <span className={`${prefixCls}-notifier-message_case-flowcode`}>工单编码：{flowNo} </span>
          </p>
        )}
        <p>{content}</p>
      </div>
      <p className={`${prefixCls}-notifier-message-time`}>{message.time}</p>
    </div>
  );
};

export default Case;
